/*
 * Copyright (C) 2017 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

syntax = "proto2";
package android.providers.settings;

option java_multiple_files = true;
option java_outer_classname = "SettingsServiceProto";

import "frameworks/base/core/proto/android/providers/settings/config.proto";
import "frameworks/base/core/proto/android/providers/settings/generation.proto";
import "frameworks/base/core/proto/android/providers/settings/global.proto";
import "frameworks/base/core/proto/android/providers/settings/secure.proto";
import "frameworks/base/core/proto/android/providers/settings/system.proto";
import "frameworks/base/core/proto/android/privacy.proto";

message SettingsServiceDumpProto {
    option (android.msg_privacy).dest = DEST_EXPLICIT;

    // Per user settings
    repeated UserSettingsProto user_settings = 1;

    // Global settings
    optional GlobalSettingsProto global_settings = 2;

    // Config settings
    optional ConfigSettingsProto config_settings = 3;

    // Generation registry stats
    optional GenerationRegistryProto generation_registry = 4;
}

message UserSettingsProto {
    option (android.msg_privacy).dest = DEST_EXPLICIT;

    // Should be 0, 10, 11, 12, etc. where 0 is the owner.
    optional int32 user_id = 1 [ (android.privacy).dest = DEST_AUTOMATIC ];

    // The secure settings for this user
    optional SecureSettingsProto secure_settings = 2;

    // The system settings for this user
    optional SystemSettingsProto system_settings = 3;
}

message SettingsProto {
    // Enum values gotten from Settings.java
    enum ScreenBrightnessMode {
        SCREEN_BRIGHTNESS_MODE_MANUAL = 0;
        SCREEN_BRIGHTNESS_MODE_AUTOMATIC = 1;
    }
}
